API
===

.. currentmodule:: pysplashsurf

Methods
-------

.. autosummary::
    check_mesh_consistency
    convert_tris_to_quads
    create_aabb_object
    create_aabb_object_from_points
    create_mesh_with_data_object
    create_sph_interpolator_object
    decimation
    marching_cubes_cleanup
    neighborhood_search_spatial_hashing_parallel
    par_laplacian_smoothing_inplace
    par_laplacian_smoothing_normals_inplace
    reconstruct_surface
    reconstruction_pipeline
    write_to_file

Classes
-------

.. autosummary::
    Aabb3dF32
    MixedTriQuadMesh3dF32
    MixedTriQuadMeshWithDataF32
    SphInterpolatorF32
    SurfaceReconstructionF32
    TriMesh3dF32
    TriMeshWithDataF32
    UniformGridF32